@@ -16,7 +16,7 @@
   GNU General Public License for more details.
 
 */
-/* $Id: silchmac.c,v 1.24.2.1 2005/05/04 08:54:05 priikone Exp $ */
+/* $Id: silchmac.c,v 1.24.2.4 2005/11/19 20:46:00 priikone Exp $ */
 
 #include "silcincludes.h"
 
@@ -39,8 +39,10 @@ SilcDList silc_hmac_list = NULL;
 /* Default hmacs for silc_hmac_register_default(). */
 const SilcHmacObject silc_default_hmacs[] =
 {
+  { "hmac-sha256-96", 12 },
   { "hmac-sha1-96", 12 },
   { "hmac-md5-96", 12 },
+  { "hmac-sha256", 32 },
   { "hmac-sha1", 20 },
   { "hmac-md5", 16 },
 
@@ -52,7 +54,7 @@ static void silc_hmac_init_internal(SilcHmac hmac, unsigned char *key,
 {
   SilcHash hash = hmac->hash;
   SilcUInt32 block_len;
-  unsigned char hvalue[20];
+  unsigned char hvalue[SILC_HASH_MAXLEN];
   int i;
 
   memset(hmac->inner_pad, 0, sizeof(hmac->inner_pad));
@@ -403,7 +405,7 @@ void silc_hmac_make_truncated(SilcHmac hmac, unsigned char *data,
 			      SilcUInt32 truncated_len,
 			      unsigned char *return_hash)
 {
-  unsigned char hvalue[20];
+  unsigned char hvalue[SILC_HASH_MAXLEN];
 
   SILC_LOG_DEBUG(("Making HMAC for message"));
 
@@ -447,7 +449,7 @@ void silc_hmac_final(SilcHmac hmac, unsigned char *return_hash,
 		     SilcUInt32 *return_len)
 {
   SilcHash hash = hmac->hash;
-  unsigned char mac[20];
+  unsigned char mac[SILC_HASH_MAXLEN];
 
   silc_hash_final(hash, mac);
   silc_hash_init(hash);
